searchData={"items":[{"type":"module","title":"HipcallOpenai","doc":"Documentation for `HipcallOpenai`.","ref":"HipcallOpenai.html"},{"type":"function","title":"HipcallOpenai.audio_create_speech/1","doc":"Create an audio from text.\n\nFor more information\n\n- https://platform.openai.com/docs/guides/text-to-speech\n- https://platform.openai.com/docs/api-reference/audio/createSpeech","ref":"HipcallOpenai.html#audio_create_speech/1"},{"type":"function","title":"Examples - HipcallOpenai.audio_create_speech/1","doc":"iex> %HipcallOpenai.Config{\n    iex>   api_key: \"YOUR_TOKEN_HERE\",\n    iex>   api_organization: \"YOUR_ORG_KEY_HERE\",\n    iex>   api_url: nil\n    iex> }\n    iex> params = [\n    iex>   model: \"tts-1\",\n    iex>   input: \"Hello, I'm an Elixir wrapper for OpenAI.\",\n    iex>   voice: \"nova\"\n    iex> ]\n    iex> HipcallOpenai.audio_create_speech(params, config_override)\n    ...> {:ok, <<255, 243, 228, 196, 0, 103, 84, 58, 0, 5, 90, 208, 0, 1, 141, 82, 99, 56, 64,\n    ...> 88, 0, 132, 9, 139, 34, 101, 75, 153, 147, 38, 100, 201, 155, 42, 104, 14,\n    ...> 25, 227, 198, 120, 241, 158, 56, 102, 139, 25, 66, 6, ...>>}\n\nYou can easily create a new mp3 file. For example\n\n    iex> {:ok, file_content} = HipcallOpenai.audio_create_speech(params, config_override)\n    iex> File.write!(\"test.mp3\", file_content)\n    ...> :ok","ref":"HipcallOpenai.html#audio_create_speech/1-examples"},{"type":"function","title":"Arguments - HipcallOpenai.audio_create_speech/1","doc":"* `:model` (`t:String.t/0`) - Required. One of the available TTS models: `tts-1` or `tts-1-hd` The default value is `\"tts-1\"`.\n\n* `:input` (`t:String.t/0`) - Required. The text to generate audio for. The maximum length is 4096 characters. The default value is `\"Hello world!\"`.\n\n* `:voice` (`t:String.t/0`) - Required. The voice to use when generating the audio. Supported voices are `alloy`, `echo`, `fable`, `onyx`, `nova`, and `shimmer`. Previews of the voices are available in the Text to speech guide. The default value is `\"nova\"`.\n\n* `:response_format` (`t:String.t/0`) - The voice to use when generating the audio. Supported voices are `alloy`, `echo`, `fable`, `onyx`, `nova`, and `shimmer`. Previews of the voices are available in the Text to speech guide. The default value is `\"mp3\"`.\n\n* `:speed` (`t:float/0`) - The speed of the generated audio. Select a value from 0.25 to 4.0. 1.0 is the default. The default value is `1.0`.","ref":"HipcallOpenai.html#audio_create_speech/1-arguments"},{"type":"function","title":"Raises - HipcallOpenai.audio_create_speech/1","doc":"- Raise `NimbleOptions.ValidationError` if params are not valid.","ref":"HipcallOpenai.html#audio_create_speech/1-raises"},{"type":"function","title":"Returns - HipcallOpenai.audio_create_speech/1","doc":"- `{:ok, file_content}`\n  - `{:error, Exception.t()}`","ref":"HipcallOpenai.html#audio_create_speech/1-returns"},{"type":"function","title":"HipcallOpenai.audio_create_speech/2","doc":"The same `audio_create_speech/1` just overwrite config.","ref":"HipcallOpenai.html#audio_create_speech/2"},{"type":"function","title":"HipcallOpenai.chat_completions/1","doc":"Create chat completion\n\nFor more information  https://platform.openai.com/docs/api-reference/chat/create","ref":"HipcallOpenai.html#chat_completions/1"},{"type":"function","title":"Examples - HipcallOpenai.chat_completions/1","doc":"iex> params = [\n    iex>   model: \"gpt-4-1106-preview\",\n    iex>   messages: [\n    iex>     %{role: \"system\", content: \"Sen yardımcı olan bir asistansın.\"},\n    iex>     %{role: \"user\", content: \"Merhaba!\"}\n    iex>   ]\n    iex> ]\n    iex> HipcallOpenai.chat_completions(params)\n    ...> {:ok,\n    ...>   %{\n    ...>     \"choices\" => [\n    ...>       %{\n    ...>         \"finish_reason\" => \"stop\",\n    ...>         \"index\" => 0,\n    ...>         \"logprobs\" => nil,\n    ...>         \"message\" => %{\n    ...>           \"content\" => \"Merhaba! Size nasıl yardımcı olabilirim?\",\n    ...>           \"role\" => \"assistant\"\n    ...>         }\n    ...>       }\n    ...>     ],\n    ...>     \"created\" => 1705330002,\n    ...>     \"id\" => \"chatcmpl-8hIWYa9L3HBatp1Wyp5fJfneaBMUi\",\n    ...>     \"model\" => \"gpt-4-1106-preview\",\n    ...>     \"object\" => \"chat.completion\",\n    ...>     \"system_fingerprint\" => \"fp_168383a679\",\n    ...>     \"usage\" => %{\n    ...>       \"completion_tokens\" => 15,\n    ...>       \"prompt_tokens\" => 27,\n    ...>       \"total_tokens\" => 42\n    ...>     }\n    ...>   }}","ref":"HipcallOpenai.html#chat_completions/1-examples"},{"type":"function","title":"Arguments - HipcallOpenai.chat_completions/1","doc":"* `:model` (`t:String.t/0`) - ID of the model to use. See the model endpoint compatibility table for\n  details on which models work with the Chat API. The default value is `\"gpt-3.5-turbo\"`.\n\n* `:messages` (list of `t:map/0`) - A list of messages comprising the conversation so far. The default value is `[%{role: \"system\", content: \"You are a helpful assistant.\"}, %{role: \"user\", content: \"Hello!\"}]`.\n\n* `:frequency_penalty` (`t:float/0`) - Number between -2.0 and 2.0. Positive values penalize new tokens based on\n  their existing frequency in the text so far, decreasing the model's\n  likelihood to repeat the same line verbatim.\n\n* `:max_tokens` (`t:pos_integer/0`) - The maximum number of tokens that can be generated in the chat completion.\n  The total length of input tokens and generated tokens is limited by the\n  model's context length.\n\n* `:stream` (`t:boolean/0`) - If set, partial message deltas will be sent, like in ChatGPT. Tokens will\n  be sent as data-only server-sent events as they become available, with\n  the stream terminated by a data: [DONE] message.\n\n* `:temperature` (`t:float/0`) - What sampling temperature to use, between 0 and 2. Higher values like 0.8\n  will make the output more random, while lower values like 0.2 will make\n  it more focused and deterministic.\n\n* `:user` (`t:String.t/0`) - A unique identifier representing your end-user, which can help OpenAI\n  to monitor and detect abuse.","ref":"HipcallOpenai.html#chat_completions/1-arguments"},{"type":"function","title":"Raises - HipcallOpenai.chat_completions/1","doc":"- Raise `NimbleOptions.ValidationError` if params are not valid.","ref":"HipcallOpenai.html#chat_completions/1-raises"},{"type":"function","title":"Returns - HipcallOpenai.chat_completions/1","doc":"- `{:ok, Finch.Response.t()}`\n  - `{:error, Exception.t()}`","ref":"HipcallOpenai.html#chat_completions/1-returns"},{"type":"function","title":"HipcallOpenai.chat_completions/2","doc":"The same `chat_completions/1` just overwrite config.","ref":"HipcallOpenai.html#chat_completions/2"},{"type":"function","title":"HipcallOpenai.model/1","doc":"Retrieve model\n\nFor more information https://platform.openai.com/docs/api-reference/models/retrieve","ref":"HipcallOpenai.html#model/1"},{"type":"function","title":"Examples - HipcallOpenai.model/1","doc":"iex> iex(1)> iex(1)> HipcallOpenai.model(\"gpt-3.5-turbo-instruct\")\n    ...> {:ok,\n    ...>  %{\n    ...>    \"created\" => 1692901427,\n    ...>    \"id\" => \"gpt-3.5-turbo-instruct\",\n    ...>    \"object\" => \"model\",\n    ...>    \"owned_by\" => \"system\"\n    ...>  }}","ref":"HipcallOpenai.html#model/1-examples"},{"type":"function","title":"Arguments - HipcallOpenai.model/1","doc":"- `model`","ref":"HipcallOpenai.html#model/1-arguments"},{"type":"function","title":"Raises - HipcallOpenai.model/1","doc":"There is no exceptions.","ref":"HipcallOpenai.html#model/1-raises"},{"type":"function","title":"Returns - HipcallOpenai.model/1","doc":"- `{:ok, map()}`\n  - `{:error, Exception.t()}`","ref":"HipcallOpenai.html#model/1-returns"},{"type":"function","title":"HipcallOpenai.model/2","doc":"The same with `model/1` just overwrite the config.","ref":"HipcallOpenai.html#model/2"},{"type":"function","title":"HipcallOpenai.models/1","doc":"List models\n\nFor more information  https://platform.openai.com/docs/api-reference/models","ref":"HipcallOpenai.html#models/1"},{"type":"function","title":"Examples - HipcallOpenai.models/1","doc":"iex> iex(1)> config_override = %Config{api_key: \"asdf_api\"}\n    iex> iex(2)> HipcallOpenai.models(config_override)\n    ...> {:ok,\n    ...> %{\n    ...>   \"data\" => [\n    ...>     %{\n    ...>       \"created\" => 1686588896,\n    ...>       \"id\" => \"gpt-4-0613\",\n    ...>       \"object\" => \"model\",\n    ...>       \"owned_by\" => \"openai\"\n    ...>     },\n    ...>     %{\n    ...>       \"created\" => 1651172509,\n    ...>       \"id\" => \"curie-search-query\",\n    ...>       \"object\" => \"model\",\n    ...>       \"owned_by\" => \"openai-dev\"\n    ...>     },\n    ...>     %{\n    ...>       \"created\" => 1687882411,\n    ...>       \"id\" => \"gpt-4\",\n    ...>       \"object\" => \"model\",\n    ...>       \"owned_by\" => \"openai\"\n    ...>     },\n    ...>     %{\n    ...>       \"created\" => 1651172509,\n    ...>       \"id\" => \"babbage-search-query\",\n    ...>       \"object\" => \"model\",\n    ...>       \"owned_by\" => \"openai-dev\"\n    ...>     },\n    ...>     %{\n    ...>       \"created\" => 1698785189,\n    ...>       \"id\" => \"dall-e-3\",\n    ...>       \"object\" => \"model\",\n    ...>       \"owned_by\" => \"system\"\n    ...>     }\n    ...>   ],\n    ...>   \"object\" => \"list\"\n    ...> }}","ref":"HipcallOpenai.html#models/1-examples"},{"type":"function","title":"Arguments - HipcallOpenai.models/1","doc":"- `config`","ref":"HipcallOpenai.html#models/1-arguments"},{"type":"function","title":"Raises - HipcallOpenai.models/1","doc":"- There is no exception.","ref":"HipcallOpenai.html#models/1-raises"},{"type":"function","title":"Returns - HipcallOpenai.models/1","doc":"- `{:ok, Finch.Response.t()}`\n- `{:error, Exception.t()}`","ref":"HipcallOpenai.html#models/1-returns"},{"type":"extras","title":"HipcallOpenai","doc":"# HipcallOpenai\n\nUnofficial OpenAI API Wrapper written in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - HipcallOpenai","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `hipcall_openai` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hipcall_openai, \"~> 0.3.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Configuration override - HipcallOpenai","doc":"Client library configuration can be overwritten in runtime by passing a %HipcallOpenai.Config{} \nstruct as last argument of the function you need to use. For instance if you need to use a different \napi_key you can simply do:\n\n```elixir\nconfig_override = %HipcallOpenai.Config{\n  api_key: \"mTRwVrbZ4aoHTyjMepleT3BlbkFJ7zZYazuN7F16XuY3WErl\",\n  api_organization: \"org-blalba\"\n}\n# pass the overriden configuration as last argument of the function\nHipcallOpenai.models(config_override)\n```","ref":"readme.html#configuration-override"},{"type":"extras","title":"Use - HipcallOpenai","doc":"Documentation for using, please check the `HipcallOpenai` module.","ref":"readme.html#use"},{"type":"extras","title":"Roadmap - HipcallOpenai","doc":"- [x] Add `Models` endpoint\n- [x] Add `Chat` endpoint\n- [x] Add `Audio` endpoints\n- [ ] Add `Embeddings` endpoint\n- [ ] Add `Fine-tuning` endpoint\n- [ ] Add `Files` endpoint\n- [ ] Add `Images` endpoint\n- [ ] Add `Moderations` endpoint\n- [ ] Add `Beta - Assistants` endpoint\n- [ ] Add `Beta - Threads` endpoint\n- [ ] Add `Beta - Messages` endpoint\n- [ ] Add `Beta - Runs` endpoint\n- [ ] Add `Tools` or `Utils` calculate token, etc.","ref":"readme.html#roadmap"},{"type":"extras","title":"Hipcall - HipcallOpenai","doc":"All [Hipcall](https://www.hipcall.com/en-gb/) libraries:\n\n- [HipcallDisposableEmail](https://github.com/hipcall/hipcall_disposable_email) - Simple library checking the email's domain is disposable or not.\n- [HipcallDeepgram](https://github.com/hipcall/hipcall_deepgram) - Unofficial Deepgram API Wrapper written in Elixir.\n- [HipcallOpenai](https://github.com/hipcall/hipcall_openai) - Unofficial OpenAI API Wrapper written in Elixir.\n- [HipcallWhichtech](https://github.com/hipcall/hipcall_whichtech) - Find out what the website is built with.","ref":"readme.html#hipcall"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.3.0 (2024-02-03) - Changelog","doc":"- Add `audio/speech` endpoint.\n- Improve ExDocs for developer.","ref":"changelog.html#v0-3-0-2024-02-03"},{"type":"extras","title":"v0.2.0 (2024-01-16) - Changelog","doc":"- Add `chat/completions` endpoint.\n- Improve ExDocs for developer.","ref":"changelog.html#v0-2-0-2024-01-16"},{"type":"extras","title":"v0.1.0 (2024-01-15) - Changelog","doc":"- Add CHANGELOG.md\n- Add `models` endpoint\n- Add `Config` overwrite feature\n- Add ex_docs\n- Add `Dependabot` and `ci.yml`","ref":"changelog.html#v0-1-0-2024-01-15"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 [Hipcall LTD](https://www.hipcall.com/en-gb/)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}